pub fn find_validity_mismatch(
left: &dyn Array,
right: &dyn Array,
idxs: &mut Vec<IdxSize>,
)Expand description
Find the indices of the values where the validity mismatches.
This is done recursively, meaning that a validity mismatch at a deeper level will result as at the level above at the corresponding index.
This procedure requires that
- Nulls are propagated recursively
- Lists to be
- trimmed to normalized offsets
- have the same number of child elements below each element (even nulls)